@@ -20,14 +20,15 @@ from typing import NamedTuple
 
 status_flags = NamedTuple(
     'status_flags', [
-        ('package_changed', str),
-        ('package_and_meta_changed', str),
+        ('package_rebuild', str),
+        ('package_rebuild_clean', str),
+        ('package_source_rebuild', str),
+        ('package_source_rebuild_clean', str),
         ('package_build_failed', str),
         ('package_build_succeeded', str),
         ('package_build_running', str),
         ('buildroot_setup_failed', str),
         ('buildroot_setup_succeeded', str),
-        ('package_update_request', str),
         ('package_request_accepted', str),
         ('incompatible_build_arch', str),
         ('reset_running_build', str),
@@ -154,14 +155,15 @@ class Defaults:
         :rtype: NamedTuple
         """
         return status_flags(
-            package_changed='package source changed',
-            package_and_meta_changed='package and its metadata changed',
+            package_rebuild='package rebuild requested',
+            package_rebuild_clean='package rebuild on new buildroot',
+            package_source_rebuild='package rebuild due to source change',
+            package_source_rebuild_clean='package rebuild on new buildroot due to source change',
             package_build_failed='package build failed',
             package_build_succeeded='package build succeeded',
             package_build_running='package build running',
             buildroot_setup_failed='build root setup failed',
             buildroot_setup_succeeded='build root setup succeeded',
-            package_update_request='fetch service update request scheduled',
             package_request_accepted='package request accepted',
             incompatible_build_arch='incompatible build arch',
             reset_running_build='reset running build',
